# Change Log

## [0.4.1](https://github.com/dldevinc/ssi-views/tree/v0.4.1) - 2023-01-09

### Features

- Add Python 3.11 support (no code changes were needed, but now we test this release).

## [0.4.0](https://github.com/dldevinc/ssi-views/tree/v0.4.0) - 2022-08-15

### Features

-   Added support for Django 4.1.

## [0.3.0](https://github.com/dldevinc/ssi-views/tree/v0.3.0) - 2022-05-28

### ⚠ BREAKING CHANGES

-   Dropped support for Python 3.5.

## [0.2.0](https://github.com/dldevinc/ssi-views/tree/v0.2.0) - 2022-01-13

-   Add support for Python 3.10
-   Add support for Django 3.2, 4.0

## [0.1.1](https://github.com/dldevinc/ssi-views/tree/v0.1.1) - 2021-02-08

-   Fix Travis
-   Add README.md

## [0.1.0](https://github.com/dldevinc/ssi-views/tree/v0.1.0) - 2021-02-08

-   First release
